==> findbugs-maven-plugin-3.0.4-sources.jar: org/codehaus/mojo/findbugs/FindBugsMojo.java <==
package org.codehaus.mojo.findbugs;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@org.apache.maven.plugins.annotations.Mojo(requiresDependencyResolution=org.apache.maven.plugins.annotations.ResolutionScope.TEST, name="findbugs", threadSafe=true, requiresProject=true) public class FindBugsMojo
  extends org.apache.maven.reporting.AbstractMavenReport  implements
    groovy.lang.GroovyObject {
;
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  void setOutputDirectory(java.io.File value) { }
public  boolean getXmlOutput() { return false;}
public  boolean isXmlOutput() { return false;}
public  void setXmlOutput(boolean value) { }
public  java.io.File getXmlOutputDirectory() { return (java.io.File)null;}
public  void setXmlOutputDirectory(java.io.File value) { }
public  boolean getFindbugsXmlOutput() { return false;}
public  boolean isFindbugsXmlOutput() { return false;}
public  void setFindbugsXmlOutput(boolean value) { }
public  java.io.File getFindbugsXmlOutputDirectory() { return (java.io.File)null;}
public  void setFindbugsXmlOutputDirectory(java.io.File value) { }
public  void setSiteRenderer(org.apache.maven.doxia.siterenderer.Renderer value) { }
public  java.io.File getClassFilesDirectory() { return (java.io.File)null;}
public  void setClassFilesDirectory(java.io.File value) { }
public  java.io.File getTestClassFilesDirectory() { return (java.io.File)null;}
public  void setTestClassFilesDirectory(java.io.File value) { }
public  java.io.File getXrefLocation() { return (java.io.File)null;}
public  void setXrefLocation(java.io.File value) { }
public  java.io.File getXrefTestLocation() { return (java.io.File)null;}
public  void setXrefTestLocation(java.io.File value) { }
public  java.util.List getCompileSourceRoots() { return (java.util.List)null;}
public  void setCompileSourceRoots(java.util.List value) { }
public  java.util.List getTestSourceRoots() { return (java.util.List)null;}
public  void setTestSourceRoots(java.util.List value) { }
public  boolean getIncludeTests() { return false;}
public  boolean isIncludeTests() { return false;}
public  void setIncludeTests(boolean value) { }
public  java.util.List getPluginArtifacts() { return (java.util.List)null;}
public  void setPluginArtifacts(java.util.List value) { }
public  java.util.List getRemoteRepositories() { return (java.util.List)null;}
public  void setRemoteRepositories(java.util.List value) { }
public  org.apache.maven.artifact.repository.ArtifactRepository getLocalRepository() { return (org.apache.maven.artifact.repository.ArtifactRepository)null;}
public  void setLocalRepository(org.apache.maven.artifact.repository.ArtifactRepository value) { }
public  java.util.List getRemoteArtifactRepositories() { return (java.util.List)null;}
public  void setRemoteArtifactRepositories(java.util.List value) { }
public  void setProject(org.apache.maven.project.MavenProject value) { }
public  java.lang.String getXmlEncoding() { return (java.lang.String)null;}
public  void setXmlEncoding(java.lang.String value) { }
public  java.lang.String getSourceEncoding() { return (java.lang.String)null;}
public  void setSourceEncoding(java.lang.String value) { }
public  java.lang.String getOutputEncoding() { return (java.lang.String)null;}
public  void setOutputEncoding(java.lang.String value) { }
public  java.lang.String getThreshold() { return (java.lang.String)null;}
public  void setThreshold(java.lang.String value) { }
public  org.apache.maven.artifact.resolver.ArtifactResolver getArtifactResolver() { return (org.apache.maven.artifact.resolver.ArtifactResolver)null;}
public  void setArtifactResolver(org.apache.maven.artifact.resolver.ArtifactResolver value) { }
public  org.apache.maven.artifact.factory.ArtifactFactory getFactory() { return (org.apache.maven.artifact.factory.ArtifactFactory)null;}
public  void setFactory(org.apache.maven.artifact.factory.ArtifactFactory value) { }
public  java.lang.String getIncludeFilterFile() { return (java.lang.String)null;}
public  void setIncludeFilterFile(java.lang.String value) { }
public  java.lang.String getExcludeFilterFile() { return (java.lang.String)null;}
public  void setExcludeFilterFile(java.lang.String value) { }
public  java.lang.String getExcludeBugsFile() { return (java.lang.String)null;}
public  void setExcludeBugsFile(java.lang.String value) { }
public  java.lang.String getEffort() { return (java.lang.String)null;}
public  void setEffort(java.lang.String value) { }
public  java.lang.Boolean getDebug() { return (java.lang.Boolean)null;}
public  void setDebug(java.lang.Boolean value) { }
public  java.lang.Boolean getRelaxed() { return (java.lang.Boolean)null;}
public  void setRelaxed(java.lang.Boolean value) { }
public  java.lang.String getVisitors() { return (java.lang.String)null;}
public  void setVisitors(java.lang.String value) { }
public  java.lang.String getOmitVisitors() { return (java.lang.String)null;}
public  void setOmitVisitors(java.lang.String value) { }
public  java.lang.String getPluginList() { return (java.lang.String)null;}
public  void setPluginList(java.lang.String value) { }
public  org.codehaus.mojo.findbugs.PluginArtifact[] getPlugins() { return (org.codehaus.mojo.findbugs.PluginArtifact[])null;}
public  void setPlugins(org.codehaus.mojo.findbugs.PluginArtifact... value) { }
public  java.lang.String getOnlyAnalyze() { return (java.lang.String)null;}
public  void setOnlyAnalyze(java.lang.String value) { }
public  java.lang.Boolean getNested() { return (java.lang.Boolean)null;}
public  void setNested(java.lang.Boolean value) { }
public  java.lang.Boolean getTrace() { return (java.lang.Boolean)null;}
public  void setTrace(java.lang.Boolean value) { }
public  int getMaxRank() { return (int)0;}
public  void setMaxRank(int value) { }
public  boolean getSkip() { return false;}
public  boolean isSkip() { return false;}
public  void setSkip(boolean value) { }
public  org.codehaus.plexus.resource.ResourceManager getResourceManager() { return (org.codehaus.plexus.resource.ResourceManager)null;}
public  void setResourceManager(org.codehaus.plexus.resource.ResourceManager value) { }
public  org.apache.maven.doxia.tools.SiteTool getSiteTool() { return (org.apache.maven.doxia.tools.SiteTool)null;}
public  void setSiteTool(org.apache.maven.doxia.tools.SiteTool value) { }
public  boolean getFailOnError() { return false;}
public  boolean isFailOnError() { return false;}
public  void setFailOnError(boolean value) { }
public  boolean getFork() { return false;}
public  boolean isFork() { return false;}
public  void setFork(boolean value) { }
public  int getMaxHeap() { return (int)0;}
public  void setMaxHeap(int value) { }
public  int getTimeout() { return (int)0;}
public  void setTimeout(int value) { }
public  java.lang.String getJvmArgs() { return (java.lang.String)null;}
public  void setJvmArgs(java.lang.String value) { }
public  boolean getSkipEmptyReport() { return false;}
public  boolean isSkipEmptyReport() { return false;}
public  void setSkipEmptyReport(boolean value) { }
public  java.lang.String getUserPrefs() { return (java.lang.String)null;}
public  void setUserPrefs(java.lang.String value) { }
public  int getBugCount() { return (int)0;}
public  void setBugCount(int value) { }
public  int getErrorCount() { return (int)0;}
public  void setErrorCount(int value) { }
public  java.util.ResourceBundle getBundle() { return (java.util.ResourceBundle)null;}
public  void setBundle(java.util.ResourceBundle value) { }
public  java.io.File getOutputFindbugsFile() { return (java.io.File)null;}
public  void setOutputFindbugsFile(java.io.File value) { }
public  boolean canGenerateReport() { return false;}
public  java.lang.String getDescription(java.util.Locale locale) { return (java.lang.String)null;}
public  java.lang.String getName(java.util.Locale locale) { return (java.lang.String)null;}
public  java.lang.String getOutputName() { return (java.lang.String)null;}
public  void executeReport(java.util.Locale locale) { }
public  void execute() { }
protected  java.lang.String getOutputDirectory() { return (java.lang.String)null;}
protected  org.apache.maven.project.MavenProject getProject() { return (org.apache.maven.project.MavenProject)null;}
protected  org.apache.maven.doxia.siterenderer.Renderer getSiteRenderer() { return (org.apache.maven.doxia.siterenderer.Renderer)null;}
protected  boolean isJxrPluginEnabled() { return false;}
public  java.util.ResourceBundle getBundle(java.lang.Object locale) { return (java.util.ResourceBundle)null;}
protected  java.lang.String getThresholdParameter() { return (java.lang.String)null;}
protected  java.lang.String getEffortParameter() { return (java.lang.String)null;}
protected  java.io.File getResourceFile(java.lang.String resource) { return (java.io.File)null;}
protected  java.lang.String getFindbugsPlugins() { return (java.lang.String)null;}
public  void setReportOutputDirectory(java.io.File reportOutputDirectory) { }
protected  java.util.List getJavaSources(java.util.Locale locale) { return (java.util.List)null;}
public  java.io.File getResourceAsFile(java.lang.String name, java.lang.String outputPath, java.io.File outputDirectory) { return (java.io.File)null;}
}

==> findbugs-maven-plugin-3.0.5-sources.jar: org/codehaus/mojo/findbugs/FindBugsMojo.java <==
package org.codehaus.mojo.findbugs;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@org.apache.maven.plugins.annotations.Mojo(name="findbugs", requiresDependencyResolution=org.apache.maven.plugins.annotations.ResolutionScope.TEST, requiresProject=true, threadSafe=true) public class FindBugsMojo
  extends org.apache.maven.reporting.AbstractMavenReport  implements
    groovy.lang.GroovyObject {
;
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  void setOutputDirectory(java.io.File value) { }
public  boolean getXmlOutput() { return false;}
public  boolean isXmlOutput() { return false;}
public  void setXmlOutput(boolean value) { }
public  java.io.File getXmlOutputDirectory() { return (java.io.File)null;}
public  void setXmlOutputDirectory(java.io.File value) { }
public  boolean getFindbugsXmlOutput() { return false;}
public  boolean isFindbugsXmlOutput() { return false;}
public  void setFindbugsXmlOutput(boolean value) { }
public  java.io.File getFindbugsXmlOutputDirectory() { return (java.io.File)null;}
public  void setFindbugsXmlOutputDirectory(java.io.File value) { }
public  void setSiteRenderer(org.apache.maven.doxia.siterenderer.Renderer value) { }
public  java.io.File getClassFilesDirectory() { return (java.io.File)null;}
public  void setClassFilesDirectory(java.io.File value) { }
public  java.io.File getTestClassFilesDirectory() { return (java.io.File)null;}
public  void setTestClassFilesDirectory(java.io.File value) { }
public  java.io.File getXrefLocation() { return (java.io.File)null;}
public  void setXrefLocation(java.io.File value) { }
public  java.io.File getXrefTestLocation() { return (java.io.File)null;}
public  void setXrefTestLocation(java.io.File value) { }
public  java.util.List getCompileSourceRoots() { return (java.util.List)null;}
public  void setCompileSourceRoots(java.util.List value) { }
public  java.util.List getTestSourceRoots() { return (java.util.List)null;}
public  void setTestSourceRoots(java.util.List value) { }
public  boolean getIncludeTests() { return false;}
public  boolean isIncludeTests() { return false;}
public  void setIncludeTests(boolean value) { }
public  java.util.List getPluginArtifacts() { return (java.util.List)null;}
public  void setPluginArtifacts(java.util.List value) { }
public  java.util.List getRemoteRepositories() { return (java.util.List)null;}
public  void setRemoteRepositories(java.util.List value) { }
public  org.apache.maven.artifact.repository.ArtifactRepository getLocalRepository() { return (org.apache.maven.artifact.repository.ArtifactRepository)null;}
public  void setLocalRepository(org.apache.maven.artifact.repository.ArtifactRepository value) { }
public  java.util.List getRemoteArtifactRepositories() { return (java.util.List)null;}
public  void setRemoteArtifactRepositories(java.util.List value) { }
public  void setProject(org.apache.maven.project.MavenProject value) { }
public  java.lang.String getXmlEncoding() { return (java.lang.String)null;}
public  void setXmlEncoding(java.lang.String value) { }
public  java.lang.String getSourceEncoding() { return (java.lang.String)null;}
public  void setSourceEncoding(java.lang.String value) { }
public  java.lang.String getOutputEncoding() { return (java.lang.String)null;}
public  void setOutputEncoding(java.lang.String value) { }
public  java.lang.String getThreshold() { return (java.lang.String)null;}
public  void setThreshold(java.lang.String value) { }
public  org.apache.maven.artifact.resolver.ArtifactResolver getArtifactResolver() { return (org.apache.maven.artifact.resolver.ArtifactResolver)null;}
public  void setArtifactResolver(org.apache.maven.artifact.resolver.ArtifactResolver value) { }
public  org.apache.maven.artifact.factory.ArtifactFactory getFactory() { return (org.apache.maven.artifact.factory.ArtifactFactory)null;}
public  void setFactory(org.apache.maven.artifact.factory.ArtifactFactory value) { }
public  java.lang.String getIncludeFilterFile() { return (java.lang.String)null;}
public  void setIncludeFilterFile(java.lang.String value) { }
public  java.lang.String getExcludeFilterFile() { return (java.lang.String)null;}
public  void setExcludeFilterFile(java.lang.String value) { }
public  java.lang.String getExcludeBugsFile() { return (java.lang.String)null;}
public  void setExcludeBugsFile(java.lang.String value) { }
public  java.lang.String getEffort() { return (java.lang.String)null;}
public  void setEffort(java.lang.String value) { }
public  java.lang.Boolean getDebug() { return (java.lang.Boolean)null;}
public  void setDebug(java.lang.Boolean value) { }
public  java.lang.Boolean getRelaxed() { return (java.lang.Boolean)null;}
public  void setRelaxed(java.lang.Boolean value) { }
public  java.lang.String getVisitors() { return (java.lang.String)null;}
public  void setVisitors(java.lang.String value) { }
public  java.lang.String getOmitVisitors() { return (java.lang.String)null;}
public  void setOmitVisitors(java.lang.String value) { }
public  java.lang.String getPluginList() { return (java.lang.String)null;}
public  void setPluginList(java.lang.String value) { }
public  org.codehaus.mojo.findbugs.PluginArtifact[] getPlugins() { return (org.codehaus.mojo.findbugs.PluginArtifact[])null;}
public  void setPlugins(org.codehaus.mojo.findbugs.PluginArtifact... value) { }
public  java.lang.String getOnlyAnalyze() { return (java.lang.String)null;}
public  void setOnlyAnalyze(java.lang.String value) { }
public  java.lang.Boolean getNested() { return (java.lang.Boolean)null;}
public  void setNested(java.lang.Boolean value) { }
public  java.lang.Boolean getTrace() { return (java.lang.Boolean)null;}
public  void setTrace(java.lang.Boolean value) { }
public  int getMaxRank() { return (int)0;}
public  void setMaxRank(int value) { }
public  boolean getSkip() { return false;}
public  boolean isSkip() { return false;}
public  void setSkip(boolean value) { }
public  org.codehaus.plexus.resource.ResourceManager getResourceManager() { return (org.codehaus.plexus.resource.ResourceManager)null;}
public  void setResourceManager(org.codehaus.plexus.resource.ResourceManager value) { }
public  org.apache.maven.doxia.tools.SiteTool getSiteTool() { return (org.apache.maven.doxia.tools.SiteTool)null;}
public  void setSiteTool(org.apache.maven.doxia.tools.SiteTool value) { }
public  boolean getFailOnError() { return false;}
public  boolean isFailOnError() { return false;}
public  void setFailOnError(boolean value) { }
public  boolean getFork() { return false;}
public  boolean isFork() { return false;}
public  void setFork(boolean value) { }
public  int getMaxHeap() { return (int)0;}
public  void setMaxHeap(int value) { }
public  int getTimeout() { return (int)0;}
public  void setTimeout(int value) { }
public  java.lang.String getJvmArgs() { return (java.lang.String)null;}
public  void setJvmArgs(java.lang.String value) { }
public  boolean getSkipEmptyReport() { return false;}
public  boolean isSkipEmptyReport() { return false;}
public  void setSkipEmptyReport(boolean value) { }
public  java.lang.String getUserPrefs() { return (java.lang.String)null;}
public  void setUserPrefs(java.lang.String value) { }
public  int getBugCount() { return (int)0;}
public  void setBugCount(int value) { }
public  int getErrorCount() { return (int)0;}
public  void setErrorCount(int value) { }
public  java.util.ResourceBundle getBundle() { return (java.util.ResourceBundle)null;}
public  void setBundle(java.util.ResourceBundle value) { }
public  java.io.File getOutputFindbugsFile() { return (java.io.File)null;}
public  void setOutputFindbugsFile(java.io.File value) { }
public  boolean canGenerateReport() { return false;}
public  java.lang.String getDescription(java.util.Locale locale) { return (java.lang.String)null;}
public  java.lang.String getName(java.util.Locale locale) { return (java.lang.String)null;}
public  java.lang.String getOutputName() { return (java.lang.String)null;}
public  void executeReport(java.util.Locale locale) { }
public  void execute() { }
protected  java.lang.String getOutputDirectory() { return (java.lang.String)null;}
protected  org.apache.maven.project.MavenProject getProject() { return (org.apache.maven.project.MavenProject)null;}
protected  org.apache.maven.doxia.siterenderer.Renderer getSiteRenderer() { return (org.apache.maven.doxia.siterenderer.Renderer)null;}
protected  boolean isJxrPluginEnabled() { return false;}
public  java.util.ResourceBundle getBundle(java.lang.Object locale) { return (java.util.ResourceBundle)null;}
protected  java.lang.String getThresholdParameter() { return (java.lang.String)null;}
protected  java.lang.String getEffortParameter() { return (java.lang.String)null;}
protected  java.io.File getResourceFile(java.lang.String resource) { return (java.io.File)null;}
protected  java.lang.String getFindbugsPlugins() { return (java.lang.String)null;}
public  void setReportOutputDirectory(java.io.File reportOutputDirectory) { }
protected  java.util.List getJavaSources(java.util.Locale locale) { return (java.util.List)null;}
public  java.io.File getResourceAsFile(java.lang.String name, java.lang.String outputPath, java.io.File outputDirectory) { return (java.io.File)null;}
}
